@@ -16,13 +16,14 @@ from autoarray.structures.grids import (
     Grid,
     GridIterate,
     GridInterpolate,
-    GridCoordinates,
+    GridIrregular,
+    GridIrregularGrouped,
     GridRectangular,
     GridVoronoi,
 )
+from autoarray import VectorFieldIrregular
 from autoarray.structures.kernel import Kernel
 from autoarray.structures.visibilities import Visibilities, VisibilitiesNoiseMap
-from autogalaxy import dimensions as dim
 from autogalaxy import util
 from autogalaxy.dataset.imaging import SettingsMaskedImaging
 from autogalaxy.dataset.interferometer import SettingsMaskedInterferometer
@@ -47,7 +48,7 @@ from autogalaxy.profiles import (
     mass_profiles as mp,
     light_and_mass_profiles as lmp,
 )
-from autogalaxy.util import convert
+from autogalaxy import convert
 
 from . import aggregator as agg
 from . import plot
@@ -85,4 +86,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = '1.7.9'
+__version__ = '1.8.5'
