@@ -1,4 +1,5 @@
 from autoconf import conf
+import autofit as af
 from autoarray.inversion import pixelizations as pix
 from autoarray.exc import PixelizationException, InversionException, GridException
 from autofit.exc import FitException
@@ -12,9 +13,7 @@ import copy
 
 
 class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
-    def __init__(
-        self, masked_imaging, settings, cosmology, image_path=None, results=None
-    ):
+    def __init__(self, masked_imaging, settings, cosmology, results=None):
 
         super().__init__(
             masked_dataset=masked_imaging,
@@ -24,12 +23,7 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
         )
 
         self.visualizer = visualizer.PhaseImagingVisualizer(
-            masked_dataset=masked_imaging, image_path=image_path, results=results
-        )
-
-        self.visualizer.visualize_hyper_images(
-            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-            hyper_model_image=self.hyper_model_image,
+            masked_dataset=masked_imaging
         )
 
     @property
@@ -70,7 +64,6 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
                 hyper_image_sky=hyper_image_sky,
                 hyper_background_noise=hyper_background_noise,
             )
-
             return fit.figure_of_merit
         except (
             PixelizationException,
@@ -93,9 +86,7 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             settings_inversion=self.settings.settings_inversion,
         )
 
-    def stochastic_log_evidences_for_instance(
-        self, instance, histogram_samples=100, histogram_bins=10
-    ):
+    def stochastic_log_evidences_for_instance(self, instance):
 
         instance = self.associate_hyper_images(instance=instance)
         tracer = self.tracer_for_instance(instance=instance)
@@ -120,7 +111,7 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
 
         log_evidences = []
 
-        for i in range(histogram_samples):
+        for i in range(self.settings.settings_lens.stochastic_samples):
 
             try:
                 log_evidence = fit.FitImaging(
@@ -144,7 +135,15 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
 
         return log_evidences
 
-    def visualize(self, instance, during_analysis):
+    def visualize(self, paths: af.Paths, instance, during_analysis):
+
+        self.visualizer.visualize_imaging(paths=paths)
+
+        self.visualizer.visualize_hyper_images(
+            paths=paths,
+            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
+            hyper_model_image=self.hyper_model_image,
+        )
 
         instance = self.associate_hyper_images(instance=instance)
         tracer = self.tracer_for_instance(instance=instance)
@@ -178,28 +177,18 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
 
         try:
             visualizer.visualize_ray_tracing(
-                tracer=fit.tracer, during_analysis=during_analysis
+                paths=paths, tracer=fit.tracer, during_analysis=during_analysis
             )
         except Exception:
             pass
 
         try:
-            visualizer.visualize_fit(fit=fit, during_analysis=during_analysis)
+            visualizer.visualize_fit(
+                paths=paths, fit=fit, during_analysis=during_analysis
+            )
         except Exception:
             pass
 
-        if not during_analysis and visualizer.plot_stochastic_histogram:
-
-            log_evidences = self.stochastic_log_evidences_for_instance(
-                instance=instance
-            )
-
-            visualizer.visualize_stochastic_histogram(
-                log_evidences=log_evidences,
-                max_log_evidence=fit.log_evidence,
-                during_analysis=during_analysis,
-            )
-
     def make_attributes(self):
         return Attributes(
             cosmology=self.cosmology,
