@@ -19,12 +19,10 @@ Each image is generated for up to 5 instruments, VRO, Euclid, HST, HST, Keck AO.
 
 # To simulate each lens, we pass it an instrument and call its simulate function.
 
-instruments = ["vro", "euclid", "hst", "hst_up", "ao"]
+instruments = ["vro"]  # , "euclid", "hst", "hst_up", "ao"]
 
 for instrument in instruments:
 
-    simulators.simulate__lens_sie__source_smooth(instrument=instrument)
-    simulators.simulate__lens_sie__source_cuspy(instrument=instrument)
-    simulators.simulate__lens_sie__source_smooth__offset_centre(instrument=instrument)
-    simulators.simulate__lens_light__source_smooth(instrument=instrument)
-    simulators.simulate__lens_light__source_cuspy(instrument=instrument)
+    simulators.simulate__mass_sie__source_sersic(instrument=instrument)
+    simulators.simulate__mass_sie__source_sersic__offset_centre(instrument=instrument)
+    simulators.simulate__light_sersic__source_sersic(instrument=instrument)
