@@ -17,7 +17,8 @@ directory = path.dirname(path.realpath(__file__))
 @pytest.fixture(name="config", autouse=True)
 def set_config_path():
     conf.instance = conf.Config(
-        path.join(directory, "../config"), path.join(directory, "../pipeline/output")
+        path.join(directory, "..", "config"),
+        path.join(directory, "..", "pipeline", "output"),
     )
     return conf.instance
 
@@ -97,19 +98,19 @@ def make_masked_imaging_7x7():
     return fixtures.make_masked_imaging_7x7()
 
 
-@pytest.fixture(name="visibilities_mask_7x2")
-def make_visibilities_mask_7x2():
-    return fixtures.make_visibilities_mask_7x2()
+@pytest.fixture(name="visibilities_mask_7")
+def make_visibilities_mask_7():
+    return fixtures.make_visibilities_mask_7()
 
 
-@pytest.fixture(name="visibilities_7x2")
+@pytest.fixture(name="visibilities_7")
 def make_visibilities_7():
     return fixtures.make_visibilities_7()
 
 
-@pytest.fixture(name="noise_map_7x2")
+@pytest.fixture(name="visibilities_noise_map_7")
 def make_noise_map_7():
-    return fixtures.make_noise_map_7()
+    return fixtures.make_visibilities_noise_map_7()
 
 
 @pytest.fixture(name="transformer_7x7_7")
